==> mingw-w64-python-fastapi-0.125.0-1.src.tar.zst: fastapi-0.125.0/docs/es/docs/deployment/fastapicloud.md <==
# FastAPI Cloud { #fastapi-cloud }

Puedes desplegar tu app de FastAPI en <a href="https://fastapicloud.com" class="external-link" target="_blank">FastAPI Cloud</a> con un solo comando; ve y únete a la lista de espera si aún no lo has hecho. 🚀

## Iniciar sesión { #login }

Asegúrate de que ya tienes una cuenta de **FastAPI Cloud** (te invitamos desde la lista de espera 😉).

Luego inicia sesión:

<div class="termy">

```console
$ fastapi login

You are logged in to FastAPI Cloud 🚀
```

</div>

## Desplegar { #deploy }

Ahora despliega tu app, con un solo comando:

<div class="termy">

```console
$ fastapi deploy

Deploying to FastAPI Cloud...

✅ Deployment successful!

🐔 Ready the chicken! Your app is ready at https://myapp.fastapicloud.dev
```

</div>

¡Eso es todo! Ahora puedes acceder a tu app en esa URL. ✨

## Acerca de FastAPI Cloud { #about-fastapi-cloud }

**<a href="https://fastapicloud.com" class="external-link" target="_blank">FastAPI Cloud</a>** está creado por el mismo autor y equipo detrás de **FastAPI**.

Agiliza el proceso de **crear**, **desplegar** y **acceder** a una API con el mínimo esfuerzo.

Aporta la misma **experiencia de desarrollador** de crear apps con FastAPI al **desplegarlas** en la nube. 🎉

También se encargará de la mayoría de las cosas que necesitas al desplegar una app, como:

* HTTPS
* Replicación, con autoescalado basado en requests
* etc.

FastAPI Cloud es el sponsor principal y proveedor de financiación de los proyectos open source de *FastAPI and friends*. ✨

## Desplegar en otros proveedores de la nube { #deploy-to-other-cloud-providers }

FastAPI es open source y está basado en estándares. Puedes desplegar apps de FastAPI en cualquier proveedor de la nube que elijas.

Sigue las guías de tu proveedor de la nube para desplegar apps de FastAPI con ellos. 🤓

## Despliega tu propio servidor { #deploy-your-own-server }

También te enseñaré más adelante en esta guía de **Despliegue** todos los detalles, para que puedas entender qué está pasando, qué tiene que ocurrir o cómo desplegar apps de FastAPI por tu cuenta, también con tus propios servidores. 🤓

==> mingw-w64-python-fastapi-0.129.2-1.src.tar.zst: fastapi-0.129.2/docs/es/docs/deployment/fastapicloud.md <==
# FastAPI Cloud { #fastapi-cloud }

Puedes desplegar tu app de FastAPI en <a href="https://fastapicloud.com" class="external-link" target="_blank">FastAPI Cloud</a> con **un solo comando**; ve y únete a la lista de espera si aún no lo has hecho. 🚀

## Iniciar sesión { #login }

Asegúrate de que ya tienes una cuenta de **FastAPI Cloud** (te invitamos desde la lista de espera 😉).

Luego inicia sesión:

<div class="termy">

```console
$ fastapi login

You are logged in to FastAPI Cloud 🚀
```

</div>

## Desplegar { #deploy }

Ahora despliega tu app, con **un solo comando**:

<div class="termy">

```console
$ fastapi deploy

Deploying to FastAPI Cloud...

✅ Deployment successful!

🐔 Ready the chicken! Your app is ready at https://myapp.fastapicloud.dev
```

</div>

¡Eso es todo! Ahora puedes acceder a tu app en esa URL. ✨

## Acerca de FastAPI Cloud { #about-fastapi-cloud }

**<a href="https://fastapicloud.com" class="external-link" target="_blank">FastAPI Cloud</a>** está creado por el mismo autor y equipo detrás de **FastAPI**.

Agiliza el proceso de **crear**, **desplegar** y **acceder** a una API con el mínimo esfuerzo.

Aporta la misma **experiencia de desarrollador** de crear apps con FastAPI al **desplegarlas** en la nube. 🎉

También se encargará de la mayoría de las cosas que necesitas al desplegar una app, como:

* HTTPS
* Replicación, con autoescalado basado en requests
* etc.

FastAPI Cloud es el sponsor principal y proveedor de financiación de los proyectos open source de *FastAPI and friends*. ✨

## Desplegar en otros proveedores de la nube { #deploy-to-other-cloud-providers }

FastAPI es open source y está basado en estándares. Puedes desplegar apps de FastAPI en cualquier proveedor de la nube que elijas.

Sigue las guías de tu proveedor de la nube para desplegar apps de FastAPI con ellos. 🤓

## Despliega tu propio servidor { #deploy-your-own-server }

También te enseñaré más adelante en esta guía de **Despliegue** todos los detalles, para que puedas entender qué está pasando, qué tiene que ocurrir o cómo desplegar apps de FastAPI por tu cuenta, también con tus propios servidores. 🤓
